@@ -31,6 +31,11 @@ ran_str = ''.join(random.choice(string.ascii_uppercase + string.ascii_lowercase
 warning_count = 0
 error_count = 0
 
+HTTP_RESPONSE_CODE_1XX = "HTTP_1XX"
+HTTP_RESPONSE_CODE_2XX = "HTTP_2XX"
+HTTP_RESPONSE_CODE_3XX = "HTTP_3XX"
+HTTP_RESPONSE_CODE_4XX = "HTTP_4XX"
+HTTP_RESPONSE_CODE_5XX = "HTTP_5XX"
 
 def set_update_count():
     global warning_count, error_count
@@ -134,10 +139,16 @@ class MigrationUtil(object):
         tenant = 'admin'
         if name and name.startswith('/'):
             parts = name.split('/', 2)
-            tenant = parts[1]
-            if not parts[2]:
-                LOG.warning('Invalid tenant ref : %s', name)
-            name = parts[2]
+            # Max length of parts is 3 assuming tenant present. If no tenant, parse just the name
+            if len(parts) == 2:
+                # e.g /test-pool
+                name = parts[1]
+            else:
+                # e.g /admin/test-pool
+                tenant = parts[1]
+                if not parts[2]:
+                    LOG.warning('Invalid tenant ref : %s', name)
+                name = parts[2]
         elif name and '/' in name:
             parts = name.split('/')
             # Changed the index to get the tenant and name in case of
