@@ -2,11 +2,14 @@
 # SPDX-License-Identifier: Apache License 2.0
 
 import logging
+
 import avi.migrationtools.f5_converter.converter_constants as final
 import avi.migrationtools.f5_converter.converter_constants as conv_const
-from avi.migrationtools.f5_converter.profile_converter import ProfileConfigConv
-from avi.migrationtools.f5_converter.conversion_util import F5Util
+import yaml
 from avi.migrationtools.avi_migration_utils import update_count
+from avi.migrationtools.f5_converter.conversion_util import F5Util
+from avi.migrationtools.f5_converter.profile_converter import ProfileConfigConv
+
 LOG = logging.getLogger(__name__)
 # Creating f5 object for util library.
 conv_utils = F5Util()
@@ -14,8 +17,8 @@ conv_utils = F5Util()
 
 class PersistenceConfigConv(object):
     @classmethod
-    def get_instance(cls, version, f5_persistence_attributes, prefix,
-                     object_merge_check):
+    def get_instance(cls, version, f5_persistence_attributes,
+                     prefix, object_merge_check):
         """
 
         :param version: version of f5 instance
@@ -24,27 +27,47 @@ class PersistenceConfigConv(object):
         :param object_merge_check: Flag for object merge
         :return:
         """
-        if version == '10':
-            return PersistenceConfigConvV10(f5_persistence_attributes, prefix,
-                                            object_merge_check)
-        if version in ['11', '12']:
-            return PersistenceConfigConvV11(f5_persistence_attributes, prefix,
-                                            object_merge_check)
+        if version == "10":
+            return PersistenceConfigConvV10(
+                f5_persistence_attributes, prefix, object_merge_check)
+        if version in ["11", "12"]:
+            return PersistenceConfigConvV11(
+                f5_persistence_attributes, prefix, object_merge_check)
 
     def convert_cookie_persistence(self, name, profile):
+        '''
+        Method for converting cookie persistence
+        '''
         pass
 
     def convert_cookie(self, name, profile, skipped, tenant):
+        '''
+        convert cookie
+        '''
         pass
 
     def convert_ssl(self, name, profile, skipped, indirect_mappings, tenant):
+        '''
+        Method for ssl conversion
+        '''
         pass
 
     def convert_source_addr(self, name, profile, skipped, tenant):
+        '''
+        Method for converting source address
+        '''
         pass
 
-    def update_conversion_status(self, conv_status, persist_mode, name,
-                                 persist_profile):
+    def update_conversion_status(
+            self,
+            conv_status,
+            persist_mode,
+            name,
+            persist_profile,
+            f5_profile):
+        '''
+        Methode to update conversion status
+        '''
         pass
 
     def update_conv_status_for_error(self, name, persist_mode, key):
@@ -53,8 +76,8 @@ class PersistenceConfigConv(object):
     def update_conv_status_for_skip(self, persist_mode, name, msg):
         pass
 
-    def convert(self, f5_config, avi_config, user_ignore, tenant_ref,
-                merge_object_mapping, sys_dict):
+    def convert(self, f5_config, avi_config, user_ignore,
+                tenant_ref, merge_object_mapping, sys_dict):
         """
 
         :param f5_config: parsed f5 config
@@ -65,10 +88,10 @@ class PersistenceConfigConv(object):
         :param sys_dict: baseline profile
         :return:
         """
-        avi_config['hash_algorithm'] = []
+        avi_config["hash_algorithm"] = []
         converted_objs = []
-        f5_persistence_dict = f5_config.get('persistence')
-        user_ignore = user_ignore.get('persistence', {})
+        f5_persistence_dict = f5_config.get("persistence")
+        user_ignore = user_ignore.get("persistence", {})
         # Added variable to get total object count.
         progressbar_count = 0
         total_size = len(f5_persistence_dict.keys())
@@ -80,9 +103,13 @@ class PersistenceConfigConv(object):
             skipped = []
             # Added call to check the progress.
             msg = "persistence conversion started..."
-            conv_utils.print_progress_bar(progressbar_count, total_size, msg,
-                             prefix='Progress', suffix='')
-            if key == 'global-settings':
+            conv_utils.print_progress_bar(
+                progressbar_count,
+                total_size,
+                msg,
+                prefix="Progress",
+                suffix="")
+            if key == "global-settings":
                 msg = 'persist mode not supported skipping conversion: %s' \
                       % name
                 LOG.warning(msg)
@@ -102,32 +129,31 @@ class PersistenceConfigConv(object):
                     name = '{}-{}'.format(self.prefix, name)
                 # Enabled the cookie support
                 if persist_mode == "cookie":
-                    persist_profile = self.convert_cookie(name, profile,
-                                                          skipped, tenant)
+                    persist_profile = self.convert_cookie(
+                        name, profile, skipped, tenant)
                     if not persist_profile:
                         continue
-                    u_ignore = user_ignore.get('cookie', [])
+                    u_ignore = user_ignore.get("cookie", [])
                 elif persist_mode == "ssl":
                     persist_profile = self.convert_ssl(
                         name, profile, skipped, self.indirect, tenant)
-                    u_ignore = user_ignore.get('ssl', [])
+                    u_ignore = user_ignore.get("ssl", [])
                 elif persist_mode == "source-addr":
                     persist_profile = self.convert_source_addr(
                         name, profile, skipped, tenant)
-                    u_ignore = user_ignore.get('source-addr', [])
+                    u_ignore = user_ignore.get("source-addr", [])
                 elif persist_mode == "hash":
-                    avi_config['hash_algorithm'].append(name)
+                    avi_config["hash_algorithm"].append(name)
                     skipped = profile.keys()
                     LOG.warn('hash-persistence profile %s will be mapped '
                              'indirectly to Pool -> Load Balance  Algorithm'
                              % name)
                     conv_status = {
-                        'status': conv_const.STATUS_PARTIAL,
-                        'skipped': skipped
-                    }
-                    msg = 'Indirectly mapped to Pool -> Load Balance Algorithm'
+                        "status": conv_const.STATUS_PARTIAL,
+                        "skipped": skipped}
+                    msg = "Indirectly mapped to Pool -> Load Balance Algorithm"
                     conv_utils.add_conv_status(
-                        'profile', "hash-persistence", name, conv_status, msg)
+                        "profile", "hash-persistence", name, conv_status, msg)
                     continue
                 else:
                     msg = 'persist mode not supported skipping conversion: %s'\
@@ -139,11 +165,18 @@ class PersistenceConfigConv(object):
                     continue
                 # code to merge applicaation persistence profile.
                 if self.object_merge_check:
-                    conv_utils.update_skip_duplicates(persist_profile,
-                                    avi_config['ApplicationPersistenceProfile'],
-                                    'app_per_profile', converted_objs, name,
-                                    None, merge_object_mapping, persist_mode,
-                         self.prefix, sys_dict['ApplicationPersistenceProfile'])
+                    conv_utils.update_skip_duplicates(
+                        persist_profile,
+                        avi_config["ApplicationPersistenceProfile"],
+                        "app_per_profile",
+                        converted_objs,
+                        name,
+                        None,
+                        merge_object_mapping,
+                        persist_mode,
+                        self.prefix,
+                        sys_dict["ApplicationPersistenceProfile"],
+                    )
                     self.app_per_count += 1
                 else:
                     avi_config["ApplicationPersistenceProfile"].append(
@@ -151,18 +184,17 @@ class PersistenceConfigConv(object):
 
                 ignore_for_defaults = {"app-service": "none", "mask": "none"}
                 conv_status = conv_utils.get_conv_status(
-                    skipped, self.indirect, ignore_for_defaults,
-                    profile, u_ignore)
-                self.update_conversion_status(conv_status, persist_mode,
-                                              name, persist_profile)
-            except:
-                update_count('error')
+                    skipped, self.indirect, ignore_for_defaults, profile, u_ignore)
+                self.update_conversion_status(
+                    conv_status, persist_mode, name, persist_profile, profile)
+            except BaseException:
+                update_count("error")
                 LOG.error("Failed to convert persistance profile : %s" % key,
                           exc_info=True)
                 self.update_conv_status_for_error(name, persist_mode, key)
         count = len(avi_config["ApplicationPersistenceProfile"])
-        LOG.debug("Converted %s persistence profiles" % count)
-        f5_config.pop('persistence')
+        LOG.debug("Converted %s persistence profiles", count)
+        f5_config.pop("persistence")
 
     def convert_timeout(self, timeout):
         """
@@ -170,21 +202,21 @@ class PersistenceConfigConv(object):
         :param timeout: timeout
         :return: timeout
         """
-        if ':' in str(timeout):
-            expiration = timeout.split(':')
+        if ":" in str(timeout):
+            expiration = timeout.split(":")
             expiration.reverse()
             timeout = 0
             i = 0
             for val in expiration:
                 val = int(val)
                 if i == 0:
-                    timeout = int(val/final.SEC_IN_MIN)
+                    timeout = int(val / final.SEC_IN_MIN)
                 elif i == 1:
                     timeout += val
                 elif i == 2:
-                    timeout += (val*final.MIN_IN_HR)
+                    timeout += val * final.MIN_IN_HR
                 elif i == 3:
-                    timeout += (val*final.MIN_IN_HR*final.HR_IN_DAY)
+                    timeout += val * final.MIN_IN_HR * final.HR_IN_DAY
                 i += 1
         else:
             timeout = 1 if int(timeout) == 0 else timeout
@@ -199,11 +231,11 @@ class PersistenceConfigConvV11(PersistenceConfigConv):
         :param prefix: prefix for object
         :param object_merge_check: flag to merge object
         """
-        self.indirect = f5_persistence_attributes['Persistence_indirect']
-        self.supported_attr = f5_persistence_attributes['Persistence_supported_attr']
-        self.supported_attr_convert = f5_persistence_attributes['Persistence_' \
-                                            'supported_attr_' \
-                                            'convert_source_addr']
+        self.indirect = f5_persistence_attributes["Persistence_indirect"]
+        self.supported_attr = f5_persistence_attributes["Persistence_supported_attr"]
+        self.supported_attr_convert = f5_persistence_attributes["Persistence_"
+                                                                "supported_attr_"
+                                                                "convert_source_addr"]
         # Added prefix for objects
         self.prefix = prefix
         self.object_merge_check = object_merge_check
@@ -218,35 +250,34 @@ class PersistenceConfigConvV11(PersistenceConfigConv):
         :param tenant: Tenant for which output to be converted
         :return:persist_profile
         """
-        method = profile.get('method', 'insert')
-        if not method == 'insert':
+        method = profile.get("method", "insert")
+        if not method == "insert":
             msg = "Skipped cookie method not supported for profile '%s' " % name
             LOG.warn(msg)
-            conv_utils.add_status_row('persistence', 'cookie', name,
-                                      final.STATUS_SKIPPED, msg)
+            conv_utils.add_status_row(
+                "persistence", "cookie", name, final.STATUS_SKIPPED, msg)
             return None
-        ignore_lst = ['always-send']
+        ignore_lst = ["always-send"]
         parent_obj = super(PersistenceConfigConvV11, self)
         self.supported_attr += ignore_lst
         skipped += [attr for attr in profile.keys()
                     if attr not in self.supported_attr]
         cookie_name = profile.get("cookie-name")
         # Set cookie name to default value from avi if not given
-        if not cookie_name or cookie_name == 'none':
-            cookie_name = 'AVI_COOKIE'
-        timeout = profile.get("expiration", '1')
+        if not cookie_name or cookie_name == "none":
+            cookie_name = "AVI_COOKIE"
+        timeout = profile.get("expiration", "1")
         timeout = parent_obj.convert_timeout(timeout)
         persist_profile = {
             "name": name,
             "http_cookie_persistence_profile": {
                 "cookie_name": cookie_name,
-                "timeout": timeout
-            },
+                "timeout": timeout},
             "server_hm_down_recovery": "HM_DOWN_PICK_NEW_SERVER",
             "persistence_type": "PERSISTENCE_TYPE_HTTP_COOKIE",
         }
-        persist_profile['tenant_ref'] = conv_utils.get_object_ref(
-            tenant, 'tenant')
+        persist_profile["tenant_ref"] = conv_utils.get_object_ref(
+            tenant, "tenant")
 
         return persist_profile
 
@@ -260,17 +291,16 @@ class PersistenceConfigConvV11(PersistenceConfigConv):
         :param tenant: Tenant for which output to be converted
         :return:
         """
-        supported_attr = ['defaults-from']
+        supported_attr = ["defaults-from"]
         skipped += [attr for attr in profile.keys()
                     if attr not in supported_attr]
         indirect_mappings.append("timeout")
         persist_profile = {
             "server_hm_down_recovery": "HM_DOWN_PICK_NEW_SERVER",
             "persistence_type": "PERSISTENCE_TYPE_TLS",
-            "name": name
-        }
-        persist_profile['tenant_ref'] = conv_utils.get_object_ref(
-                tenant, 'tenant')
+            "name": name}
+        persist_profile["tenant_ref"] = conv_utils.get_object_ref(
+            tenant, "tenant")
         return persist_profile
 
     def convert_source_addr(self, name, profile, skipped, tenant):
@@ -283,28 +313,31 @@ class PersistenceConfigConvV11(PersistenceConfigConv):
         :return: persist_profile
         """
         supported_attr = self.supported_attr_convert
-        ignore_lst = ['map-proxies']
+        ignore_lst = ["map-proxies"]
         supported_attr += ignore_lst
         skipped += [attr for attr in profile.keys()
                     if attr not in supported_attr]
         timeout = profile.get("timeout", final.SOURCE_ADDR_TIMEOUT)
-        timeout = 0 if timeout == 'indefinite' else timeout
+        timeout = 0 if timeout == "indefinite" else timeout
         if int(timeout) > 0:
-            timeout = int(timeout)/final.SEC_IN_MIN
+            timeout = int(timeout) / final.SEC_IN_MIN
         persist_profile = {
             "server_hm_down_recovery": "HM_DOWN_PICK_NEW_SERVER",
             "persistence_type": "PERSISTENCE_TYPE_CLIENT_IP_ADDRESS",
-            "ip_persistence_profile": {
-                "ip_persistent_timeout": timeout
-            },
-            "name": name
+            "ip_persistence_profile": {"ip_persistent_timeout": timeout},
+            "name": name,
         }
-        persist_profile['tenant_ref'] = conv_utils.get_object_ref(
-                tenant, 'tenant')
+        persist_profile["tenant_ref"] = conv_utils.get_object_ref(
+            tenant, "tenant")
         return persist_profile
 
-    def update_conversion_status(self, conv_status, persist_mode, name,
-                                 persist_profile):
+    def update_conversion_status(
+            self,
+            conv_status,
+            persist_mode,
+            name,
+            persist_profile,
+            f5_profile):
         """
 
         :param conv_status:  state of conversion
@@ -313,11 +346,9 @@ class PersistenceConfigConvV11(PersistenceConfigConv):
         :param persist_profile: dict of persist profile
         :return:
         """
-        conv_utils.add_conv_status('persistence', persist_mode, name,
-                                   conv_status,
-                                   [{'app_per_profile': persist_profile}])
-        LOG.debug("Conversion successful for persistence profile: %s" %
-                  name)
+        conv_utils.add_conv_status("persistence", persist_mode, name, conv_status, [
+            {"app_per_profile": persist_profile}], f5_object=yaml.dump(f5_profile))
+        LOG.debug("Conversion successful for persistence profile: %s", name)
 
     def update_conv_status_for_error(self, name, persist_mode, key):
         """
@@ -328,15 +359,19 @@ class PersistenceConfigConvV11(PersistenceConfigConv):
         :return:
         """
         if name:
-            conv_utils.add_status_row("persistence", persist_mode, name,
-                                      final.STATUS_ERROR)
+            conv_utils.add_status_row(
+                "persistence", persist_mode, name, final.STATUS_ERROR)
         else:
-            conv_utils.add_status_row("persistence", key, key,
-                                      final.STATUS_ERROR)
+            conv_utils.add_status_row(
+                "persistence", key, key, final.STATUS_ERROR)
 
     def update_conv_status_for_skip(self, persist_mode, name, msg):
-        conv_utils.add_status_row("persistence", persist_mode, name,
-                                  final.STATUS_SKIPPED, msg)
+        conv_utils.add_status_row(
+            "persistence",
+            persist_mode,
+            name,
+            final.STATUS_SKIPPED,
+            msg)
 
 
 class PersistenceConfigConvV10(PersistenceConfigConv):
@@ -347,11 +382,10 @@ class PersistenceConfigConvV10(PersistenceConfigConv):
         :param prefix: prefix for objects
         :param object_merge_check: flag to merge object
         """
-        self.indirect = f5_persistence_attributes['Persistence_indirect']
-        self.supported_attr = \
-            f5_persistence_attributes['Persistence_supported_attr']
+        self.indirect = f5_persistence_attributes["Persistence_indirect"]
+        self.supported_attr = f5_persistence_attributes["Persistence_supported_attr"]
         self.supported_attr_conver = f5_persistence_attributes[
-            'Persistence_supported_attr_convert_source_addr']
+            "Persistence_supported_attr_convert_source_addr"]
         # Added prefix for objects
         self.prefix = prefix
         self.object_merge_check = object_merge_check
@@ -366,38 +400,39 @@ class PersistenceConfigConvV10(PersistenceConfigConv):
         :param tenant: Tenant for which output to be converted
         :return:persist_profile
         """
-        method = profile.get('cookie mode', 'insert')
-        if not method == 'insert':
-            LOG.warn("Skipped cookie method not supported for profile '%s' "
-                     % name)
-            conv_utils.add_conv_status('persistence', 'cookie', name, 'skipped')
+        method = profile.get("cookie mode", "insert")
+        if not method == "insert":
+            LOG.warning(
+                "Skipped cookie method not supported for profile '%s' ",
+                name)
+            conv_utils.add_conv_status(
+                "persistence", "cookie", name, "skipped")
             return None
         skipped += [attr for attr in profile.keys()
-                   if attr not in self.supported_attr]
+                    if attr not in self.supported_attr]
         cookie_name = profile.get("cookie name")
         # Set cookie name to default value from avi if not given
-        if not cookie_name or cookie_name == 'none':
-            cookie_name = 'AVI_COOKIE'
-        timeout = profile.get("cookie expiration", '1')
-        if timeout == 'immediate':
-            timeout = '0'
+        if not cookie_name or cookie_name == "none":
+            cookie_name = "AVI_COOKIE"
+        timeout = profile.get("cookie expiration", "1")
+        if timeout == "immediate":
+            timeout = "0"
         parent_obj = super(PersistenceConfigConvV10, self)
-        if 'd ' in timeout:
-            timeout = timeout.replace('d ', ':')
-        elif 'd' in timeout:
-            timeout = timeout.replace('d', '')
+        if "d " in timeout:
+            timeout = timeout.replace("d ", ":")
+        elif "d" in timeout:
+            timeout = timeout.replace("d", "")
         timeout = parent_obj.convert_timeout(timeout)
         persist_profile = {
             "name": name,
             "http_cookie_persistence_profile": {
                 "cookie_name": cookie_name,
-                "timeout": timeout
-            },
+                "timeout": timeout},
             "server_hm_down_recovery": "HM_DOWN_PICK_NEW_SERVER",
             "persistence_type": "PERSISTENCE_TYPE_HTTP_COOKIE",
         }
-        persist_profile['tenant_ref'] = conv_utils.get_object_ref(
-                tenant, 'tenant')
+        persist_profile["tenant_ref"] = conv_utils.get_object_ref(
+            tenant, "tenant")
         return persist_profile
 
     def convert_ssl(self, name, profile, skipped, indirect, tenant):
@@ -410,17 +445,16 @@ class PersistenceConfigConvV10(PersistenceConfigConv):
         :param tenant: Tenant for which output to be converted
         :return:
         """
-        supported_attr = ["mode", 'defaults-from']
+        supported_attr = ["mode", "defaults-from"]
         skipped += [attr for attr in profile.keys()
                     if attr not in supported_attr]
         indirect.append("timeout")
         persist_profile = {
             "server_hm_down_recovery": "HM_DOWN_PICK_NEW_SERVER",
             "persistence_type": "PERSISTENCE_TYPE_TLS",
-            "name": name
-        }
-        persist_profile['tenant_ref'] = conv_utils.get_object_ref(
-                tenant, 'tenant')
+            "name": name}
+        persist_profile["tenant_ref"] = conv_utils.get_object_ref(
+            tenant, "tenant")
         return persist_profile
 
     def convert_source_addr(self, name, profile, skipped, tenant):
@@ -438,21 +472,24 @@ class PersistenceConfigConvV10(PersistenceConfigConv):
                     if attr not in supported_attr]
         timeout = profile.get("timeout", final.SOURCE_ADDR_TIMEOUT)
         if int(timeout) > 0:
-            timeout = int(timeout)/final.SEC_IN_MIN
+            timeout = int(timeout) / final.SEC_IN_MIN
         persist_profile = {
-          "server_hm_down_recovery": "HM_DOWN_PICK_NEW_SERVER",
-          "persistence_type": "PERSISTENCE_TYPE_CLIENT_IP_ADDRESS",
-          "ip_persistence_profile": {
-            "ip_persistent_timeout": timeout
-          },
-          "name": name
+            "server_hm_down_recovery": "HM_DOWN_PICK_NEW_SERVER",
+            "persistence_type": "PERSISTENCE_TYPE_CLIENT_IP_ADDRESS",
+            "ip_persistence_profile": {"ip_persistent_timeout": timeout},
+            "name": name,
         }
-        persist_profile['tenant_ref'] = conv_utils.get_object_ref(
-                tenant, 'tenant')
+        persist_profile["tenant_ref"] = conv_utils.get_object_ref(
+            tenant, "tenant")
         return persist_profile
 
-    def update_conversion_status(self, conv_status, persist_mode, name,
-                                 persist_profile):
+    def update_conversion_status(
+            self,
+            conv_status,
+            persist_mode,
+            name,
+            persist_profile,
+            f5_profile):
         """
 
         :param conv_status:  state of conversion
@@ -461,10 +498,9 @@ class PersistenceConfigConvV10(PersistenceConfigConv):
         :param persist_profile: dict of persist profile
         :return:
         """
-        conv_utils.add_conv_status('persistence', 'persist', name, conv_status,
-                                   [{'app_per_profile': persist_profile}])
-        LOG.debug("Conversion successful for persistence profile: %s" %
-                  name)
+        conv_utils.add_conv_status("persistence", "persist", name, conv_status, [
+            {"app_per_profile": persist_profile}], f5_object=yaml.dump(f5_profile))
+        LOG.debug("Conversion successful for persistence profile: %s", name)
 
     def update_conv_status_for_error(self, name, persist_mode, key):
         """
@@ -475,11 +511,11 @@ class PersistenceConfigConvV10(PersistenceConfigConv):
         :return:
         """
         if name:
-            conv_utils.add_status_row("persistence", 'persist', name,
-                                      final.STATUS_ERROR)
+            conv_utils.add_status_row(
+                "persistence", "persist", name, final.STATUS_ERROR)
         else:
-            conv_utils.add_status_row("persistence", 'persist', key,
-                                      final.STATUS_ERROR)
+            conv_utils.add_status_row(
+                "persistence", "persist", key, final.STATUS_ERROR)
 
     def update_conv_status_for_skip(self, persist_mode, name, msg):
         """
@@ -489,5 +525,9 @@ class PersistenceConfigConvV10(PersistenceConfigConv):
         :param msg: status message
         :return:
         """
-        conv_utils.add_status_row("persistence", 'persist', name,
-                                  final.STATUS_SKIPPED, msg)
+        conv_utils.add_status_row(
+            "persistence",
+            "persist",
+            name,
+            final.STATUS_SKIPPED,
+            msg)
