@@ -287,7 +287,7 @@ class MonitorConverter(object):
 
                 custom_header = ns_monitor.get('customHeaders')
                 if custom_header:
-                    avi_monitor['https_monitor'].update({
+                    avi_monitor['https_monitor'] = {
                         'exact_http_request': True,
                         'http_request': (send + ' HTTP/1.0' + "\r\n" +
                                         custom_header + "\r\n").replace('"',
@@ -295,7 +295,7 @@ class MonitorConverter(object):
                                         send else ('HTTP/1.0' + "\r\n" +
                                         custom_header + "\r\n").replace('"',
                                         '').replace('\\r\\n', '\r\n')
-                    })
+                    }
             elif mon_type == 'HTTP':
                 avi_monitor["type"] = "HEALTH_MONITOR_HTTP"
                 send = ns_monitor.get('httpRequest', None)
