@@ -1,3 +1,6 @@
+# Copyright 2021 VMware, Inc.
+# SPDX-License-Identifier: Apache License 2.0
+
 """
 This provides an initial test cases for entity count, vs references and code
 coverage
@@ -5,7 +8,7 @@ coverage
 import os
 import json
 import re
-import urlparse
+from urllib.parse import urlparse, parse_qs
 
 from avi.migrationtools.netscaler_converter.netscaler_converter import NetscalerConverter
 
@@ -47,8 +50,8 @@ def get_name(url):
     :param url:
     :return: Name of object
     """
-    parsed = urlparse.urlparse(url)
-    return urlparse.parse_qs(parsed.query)['name'][0]
+    parsed = urlparse(url)
+    return parse_qs(parsed.query)['name'][0]
 
 
 def http_policies_references_vs(avi_config):
