@@ -196,6 +196,8 @@ class PolicyConfigConverter(object):
                                 elif rule_dict.__contains__('redirect_action') or rule_dict.__contains__(
                                         'switching_action'):
                                     http_rules.append(rule_dict)
+                                elif rule_dict.__contains__('action'):
+                                    sec_rules.append(rule_dict)
                 if match_strategy == "ANY" and match_conditions:
                     supp_match_conditions = list()
                     for match_condition in match_conditions:
@@ -259,6 +261,8 @@ class PolicyConfigConverter(object):
                                 elif rule_dict.__contains__('redirect_action') or rule_dict.__contains__(
                                         'switching_action'):
                                     http_rules.append(rule_dict)
+                                elif rule_dict.__contains__('action'):
+                                    sec_rules.append(rule_dict)
         ds_counter = 1
         for index, rule in enumerate(http_rules):
             counter = index + 1
@@ -283,7 +287,7 @@ class PolicyConfigConverter(object):
             [], indirect, ignore_for_defaults, [],
             u_ignore, [])
 
-        if http_rules or sec_rules or rsp_rules or self.policy_datascript_obj:
+        if http_rules or sec_rules or rsp_rules:
             conv_status["skipped"] = skipped_rule
             conv_status["na_list"] = []
             if not skipped_rule:
@@ -514,6 +518,7 @@ class PolicyConfigConverter(object):
             if action["type"] == "LBVariablePersistenceLearnAction" or \
                     action['type'] == 'LBVariablePersistenceOnAction':
                 # skip rule
+                LOG.debug("Rule action of type {} skipped".format(action["type"]))
                 continue
 
             if action["type"] == "LBHttpRequestUriRewriteAction":
@@ -639,7 +644,9 @@ class PolicyConfigConverter(object):
 
         pool_present = False
         if self.lb_vs_config["id"] in vs_select_pool_action_list.keys():
-            pool_segment = vs_pool_segment_list[self.lb_vs_config["id"]].get("pool_segment")
+            pool_segment = None
+            if self.lb_vs_config["id"] in vs_pool_segment_list:
+                pool_segment = vs_pool_segment_list[self.lb_vs_config["id"]].get("pool_segment")
             is_pg_created = False
             if pool_ref:
                 p_tenant, pool_ref = conv_utils.get_tenant_ref(pool_ref)
