@@ -23,7 +23,7 @@ pool_name_dict = {}
 vs_select_pool_action_list = dict()
 
 class PoolConfigConv(object):
-    def __init__(self, nsxt_pool_attributes, object_merge_check, merge_object_mapping, sys_dict):
+    def __init__(self, nsxt_pool_attributes, object_merge_check, merge_object_mapping, sys_dict, skip_datapath_check):
         """
         :param nsxt_pool_attributes: Supported attributes for pool migration
         """
@@ -37,6 +37,7 @@ class PoolConfigConv(object):
         self.object_merge_check = object_merge_check
         self.merge_object_mapping = merge_object_mapping
         self.sys_dict = sys_dict
+        self.skip_datapath_check = skip_datapath_check
 
     def convert(self, alb_config, nsx_lb_config, nsxt_util, prefix, tenant):
         '''
@@ -91,6 +92,7 @@ class PoolConfigConv(object):
                 is_sry_pool_present = False
                 pool_skip = True
                 pool_count = 0
+                is_pool_orphan=True
                 pool_members_list = list()
                 if lb_pl.get('member_group'):
                     ns_grp_name, ip_addr_grp = nsxt_util.get_nsx_group_details(lb_pl['member_group']['group_path'])
@@ -115,28 +117,45 @@ class PoolConfigConv(object):
                     if vs_list:
                         pool_seg_list,is_member_ip_in_range,pool_skip = self.check_pool_member_ip_ranges\
                             (vs_list, pool_count, lb_list, pool_members_list, pool_skip, name, vs_pool_segment_list)
+                        is_pool_orphan=False
 
                     if vs_list_for_sorry_pool:
                         pool_seg_list,is_member_ip_in_range ,pool_skip= self.check_pool_member_ip_ranges \
                             (vs_list_for_sorry_pool, pool_count, lb_list, pool_members_list, pool_skip, name,
                              vs_sorry_pool_segment_list)
-                        if is_member_ip_in_range:
+                        if is_member_ip_in_range or self.skip_datapath_check:
                             is_sry_pool_present = True
+                        is_pool_orphan=False
 
                     if vs_list_for_rules_select_action_pool:
                         pool_seg_list,is_member_ip_in_range, pool_skip = self.check_pool_member_ip_ranges \
                             (vs_list_for_rules_select_action_pool, pool_count, lb_list, pool_members_list, pool_skip, name,
                              vs_select_pool_action_list)
+                        is_pool_orphan=False
 
-                    if pool_skip:
+
+                    if is_pool_orphan:
                         skipped_pools_list.append(name)
-                        skip_msg = 'Member ip not falling in segment range'
+                        skip_msg = 'Pool is orphan , it is not associated with any vs'
                         conv_utils.add_status_row('pool', None, lb_pl['display_name'],
                                                   conv_const.STATUS_SKIPPED, skip_msg)
                         LOG.warning("POOL {} not migrated. Reason: {}".format(name,
                                                                               skip_msg))
                         conv_utils.print_progress_bar(progressbar_count, total_size, msg, prefix='Progress', suffix='')
                         continue
+
+                    if pool_skip and not self.skip_datapath_check:
+                        skipped_pools_list.append(name)
+                        skip_msg = 'Member ip not falling in segment range.'
+                        conv_utils.add_status_row('pool', None, lb_pl['display_name'],
+                                                  conv_const.STATUS_SKIPPED, skip_msg)
+                        LOG.warning("POOL {} not migrated. Reason: {}".format(name,
+                                                                              skip_msg))
+                        conv_utils.print_progress_bar(progressbar_count, total_size, msg, prefix='Progress', suffix='')
+                        continue
+                    else:
+                        LOG.warning("Skipping datapath validation for member not falling in segment range for pool {}".
+                                    format(name))
                 else:
                     skipped_pools_list.append(name)
                     skip_msg = 'Pool does not contains members'
@@ -313,6 +332,7 @@ class PoolConfigConv(object):
             if member.get("port", ""):
                 server_obj['port'] = int(member.get("port"))
             else:
+                LOG.debug(f"No port value found for {member.get('display_name')}")
                 server_skipped.append(member.get("display_name"))
 
             if member.get("weight"):
@@ -357,12 +377,12 @@ class PoolConfigConv(object):
                 pool_bmd.append(member)
         if pool_bme and pool_bmd:
             is_pool_group = True
-            if not sorry_pool:
-                bmd_priority = "3"
-                bme_priority = "2"
-            else:
+            if sorry_pool:
                 bmd_priority = "1"
                 bme_priority = "0"
+            else:
+                bmd_priority = "3"
+                bme_priority = "2"
             priority_list = pg_dict.get(bmd_priority, [])
             priority_list = pool_bmd
             pg_dict[bmd_priority] = priority_list
@@ -374,10 +394,10 @@ class PoolConfigConv(object):
 
         elif pool_bme:
             is_pool_group = True
-            if not sorry_pool:
-                priority = "2"
-            else:
+            if sorry_pool:
                 priority = "0"
+            else:
+                priority = "2"
             priority_list = pg_dict.get(priority, [])
             priority_list = pool_bme
             pg_dict[priority] = priority_list
@@ -486,12 +506,15 @@ class PoolConfigConv(object):
         is_member_ip_in_range=False
         for member in pool_members_list:
             for vs_id in vs_list:
+                LOG.debug("Checking pool member ip  %s falling in range or not  , pool %s attached with vip %s " %
+                          (member.get("ip_address"), pool_name, vs_id))
                 if vs_id in pool_segment_list.keys():
                     pool_skip = False
                     is_member_ip_in_range=True
                     continue
                 lb = get_lb_service_name(vs_id)
                 if not lb:
+                    LOG.debug("lb not configured for vs %s" % vs_id)
                     continue
                 pool_segment = get_object_segments(vs_id,
                                                    member.get("ip_address"))
@@ -511,11 +534,18 @@ class PoolConfigConv(object):
                     else:
                         new_pool_name = '%s-%s' % (pool_name, pool_segment[0].get("subnets").get("network_range"))
                         new_pool_name = new_pool_name.replace('/', '-')
-                        vs_pool_segment_list[vs_id] = {
+                        pool_segment_list[vs_id] = {
                             "pool_name": new_pool_name,
                             "pool_segment": pool_segment
                         }
                         lb_list[lb] = pool_segment_list.get(vs_id)
                     pool_count += 1
+                elif self.skip_datapath_check:
+                    pool_segment_list[vs_id] = {
+                        "pool_name": pool_name,
+                        "pool_segment": None
+                    }
+                    pool_count += 1
 
         return pool_segment_list, is_member_ip_in_range,pool_skip
+
