@@ -211,10 +211,11 @@ class ProfileConfigConv(object):
                                                                                      conv_status['skipped']))
 
     def convert_http(self, alb_pr, lb_pr):
+        xff_enabled = True if lb_pr.get('x_forwarded_for') else False
         alb_pr['type'] = 'APPLICATION_PROFILE_TYPE_HTTP'
         alb_pr['http_profile'] = dict(
-            xff_enabled=lb_pr.get('xForwardedFor', False),
-            http_to_https=lb_pr.get('httpRedirectToHttps', False),
+            xff_enabled=xff_enabled,
+            http_to_https=lb_pr.get('http_redirect_to_https'),
             keepalive_timeout=lb_pr.get('idle_timeout'),
             # nsx-t config value in bytes, so converting from bytes to KB for ALB
             client_max_header_size=lb_pr.get('request_header_size') / 1024,
@@ -227,7 +228,7 @@ class ProfileConfigConv(object):
         alb_pr["preserve_client_ip"] = False
         if lb_pr.get("http_redirect_to"):
             # TODO
-            print("http_redirect_to")
+            LOG.debug("TODO: http_redirect_to")
 
     def convert_udp(self, alb_pr, lb_pr):
         alb_pr['profile'] = dict(
@@ -248,3 +249,12 @@ class ProfileConfigConv(object):
             session_idle_timeout=lb_pr.get('idle_timeout')
         )
         return path
+
+
+def set_certificate_mode(t_obj_body, certificate_mode):
+    if 'http_profile' in t_obj_body.keys():
+        t_obj_body['http_profile']['ssl_client_certificate_mode'] = certificate_mode
+    else:
+        t_obj_body.update({"http_profile": {
+            "ssl_client_certificate_mode": certificate_mode
+        }})
