@@ -18,7 +18,7 @@ import random
 
 from avi.migrationtools.nsxt_converter.pools_converter import skipped_pools_list, vs_pool_segment_list, \
     vs_sorry_pool_segment_list, pool_name_dict
-from avi.migrationtools.nsxt_converter.profile_converter import application_profile_list, network_profile_list
+from avi.migrationtools.nsxt_converter.profile_converter import application_profile_list, network_profile_list, set_certificate_mode
 from avi.migrationtools.nsxt_converter.ssl_profile_converter import ssl_profile_list
 
 LOG = logging.getLogger(__name__)
@@ -44,7 +44,7 @@ se_group_created_for_cloud = dict()
 
 class VsConfigConv(object):
     def __init__(self, nsxt_profile_attributes, object_merge_check, merge_object_mapping, sys_dict,
-                 nsxt_ip, nsxt_password):
+                 nsxt_ip, nsxt_password, skip_datapath_check):
         """
 
         """
@@ -67,8 +67,9 @@ class VsConfigConv(object):
         self.pki_count = 0
         self.nsxt_ip = nsxt_ip
         self.nsxt_password = nsxt_password
+        self.skip_datapath_check = skip_datapath_check
 
-    def convert(self, alb_config, nsx_lb_config, prefix, tenant, vs_state, controller_version, traffic_enabled,
+    def convert(self, alb_config, nsx_lb_config, prefix, tenant, vs_state, controller_version, traffic_state,
                 cloud_tenant, ssh_root_password, nsxt_util, migration_input_config=None, vrf=None, segroup=None):
         '''
         LBVirtualServer to Avi Config vs converter
@@ -77,6 +78,9 @@ class VsConfigConv(object):
         converted_http_policy_sets = list()
         converted_http_policy_na_list = list()
         converted_http_policy_skipped = list()
+        new_pci_app_profile_list = list()
+        new_service_engine_group_list = list()
+        new_network_service_list = list()
         indirect_client_ssl = []
         indirect_server_ssl = []
         alb_config['VirtualService'] = list()
@@ -172,13 +176,14 @@ class VsConfigConv(object):
                 vs_temp = list(filter(lambda vs: vs["name"] == name, alb_config['VirtualService']))
                 if vs_temp:
                     name = '%s-%s' % (name, lb_vs["id"])
-                enabled = lb_vs.get('enabled')
-                if enabled and vs_state:
-                    enabled = (vs_state == 'enable')
+                vs_enabled = lb_vs.get('enabled')
+                if vs_enabled and vs_state:
+                    vs_enabled = (vs_state == 'enable')
+                vs_traffic_state = (traffic_state == 'enable')
                 alb_vs = dict(
-                    name=name,
-                    traffic_enabled=(enabled and traffic_enabled),
-                    enabled=enabled,
+                    name=name.strip(),
+                    traffic_enabled=vs_traffic_state,
+                    enabled=vs_enabled,
                     cloud_ref=conv_utils.get_object_ref(cloud_name, 'cloud', cloud_tenant=cloud_tenant),
                     tenant_ref=conv_utils.get_object_ref(tenant, 'tenant')
                 )
@@ -224,20 +229,35 @@ class VsConfigConv(object):
                     else:
                         vsvip_ref = conv_utils.get_object_ref(vip["name"], 'vsvip', tenant=tenant, cloud_name=cloud_name)
                     alb_vs['vsvip_ref'] = vsvip_ref
-                alb_vs['services'] = [
-                    dict(
-                        port=int(lb_vs.get('ports')[0]),
-                        enable_ssl=False
-                    )]
+                alb_vs['services'] = []
+                ports = lb_vs.get('ports')
+                for port in ports:
+                    if isinstance(port, str) and '-' in port:
+                        port_start = port.split("-")[0]
+                        port_end_range = port.split("-")[-1]
+                        port_dict = dict(
+                            port=int(port_start),
+                            enable_ssl=False,
+                            port_range_end=port_end_range
+                        )
+                    else:
+                        port_dict = dict(
+                            port=int(port),
+                            enable_ssl=False
+                        )
+                    alb_vs['services'].append(port_dict)
                 skipped = [val for val in lb_vs.keys()
                            if val not in self.supported_attr]
                 na_list = [val for val in lb_vs.keys()
                            if val in self.common_na_attr or val in self.VS_na_attr]
+
                 if segroup:
                     segroup_ref = conv_utils.get_object_ref(
                         segroup, 'serviceenginegroup', cloud_tenant,
                         cloud_name=cloud_name)
                     alb_vs['se_group_ref'] = segroup_ref
+                else:
+                    segroup="Default-Group"
                 client_pki = False
                 server_pki = False
 
@@ -413,7 +433,7 @@ class VsConfigConv(object):
                         for profile in alb_config["ApplicationProfile"]:
                             if merge_profile_name == profile["name"]:
                                 if client_ssl["client_auth"] == 'IGNORE':
-                                    profile["ssl_client_certificate_mode"] = 'SSL_CLIENT_CERTIFICATE_NONE'
+                                    set_certificate_mode(profile, 'SSL_CLIENT_CERTIFICATE_NONE')
                     if ssl_key_cert_refs:
                         alb_vs["ssl_key_and_certificate_refs"] = list(set(ssl_key_cert_refs))
                     skipped_client_ssl = [val for val in client_ssl.keys()
@@ -541,6 +561,7 @@ class VsConfigConv(object):
                                             "tenant_ref": conv_utils.get_object_ref(tenant, 'tenant')
                                         }
                                         alb_config["ApplicationProfile"].append(new_pci_app_profile)
+                                        new_pci_app_profile_list.append(new_pci_app_profile)
                                         app_profile_pci_created = True
 
                                 pci_se_group_name = prefix if prefix else self.nsxt_ip
@@ -555,6 +576,7 @@ class VsConfigConv(object):
                                         "tenant_ref": conv_utils.get_object_ref(cloud_tenant, 'tenant')
                                     }
                                     alb_config["ServiceEngineGroup"].append(new_pci_se_group)
+                                    new_service_engine_group_list.append(new_pci_se_group)
                                     se_group_created_for_cloud[cloud_name] = new_pci_se_group
 
                                 vs_with_custom_se_group.append(lb_vs['display_name'])
@@ -571,32 +593,41 @@ class VsConfigConv(object):
                                                                         pl_config[0].get("members"))
 
                                 # Create NetworkService for the created SEGroup
-                                if not is_network_service_created.get("{}-{}".format(pci_se_group_name, tier1_lr)):
-                                    ns_name = "{}-{}".format(pci_se_group_name, "ns")
-                                    tier_name = tier1_lr.split("/")[-1]
-                                    floating_ip = "0.0.0.0"
-                                    if migration_input_config and migration_input_config.get('network_service'):
-                                        floating_ip = migration_input_config.get('network_service'). \
-                                            get("{}-{}".format(tier_name, "floating-ip"))
+                                tier_name = tier1_lr.split("/")[-1]
+                                floating_ip = "0.0.0.0"
+                                if migration_input_config and migration_input_config.get('network_service'):
+                                    floating_ip = migration_input_config.get('network_service'). \
+                                         get("{}-{}".format(tier_name, "floating-ip"))
+                                if cloud_type == "Vlan":
+                                    ns_vrf_name = "global"
+                                else:
+                                    ns_vrf_name = tier_name
+
+                                ns_name = "{}-{}-{}".format(pci_se_group_name, ns_vrf_name, "ns")
+
+                                is_network_service_created_obj = is_network_service_created.get("{}-{}-{}".format(
+                                    pci_se_group_name, cloud_name, ns_vrf_name))
+                                if is_network_service_created_obj:
+                                    for network_obj in alb_config["NetworkService"]:
+                                        if network_obj["name"] == is_network_service_created_obj["name"]:
+                                            nsxt_util.update_network_service_obj(network_obj, floating_ip)
+                                else:
                                     ns_cloud_ref = conv_utils.get_object_ref(cloud_name, 'cloud',
                                                                              cloud_tenant=cloud_tenant)
-                                    if cloud_type == "Vlan":
-                                        ns_vrf_ref = conv_utils.get_object_ref("global", 'vrfcontext',
-                                                                               cloud_name=cloud_name,
-                                                                               cloud_tenant=cloud_tenant,
-                                                                               tenant=tenant)
-                                    else:
-                                        ns_vrf_ref = conv_utils.get_object_ref(tier_name, 'vrfcontext',
-                                                                               cloud_name=cloud_name,
-                                                                               cloud_tenant=cloud_tenant,
-                                                                               tenant=tenant)
+
+                                    ns_vrf_ref = conv_utils.get_object_ref(ns_vrf_name, 'vrfcontext',
+                                                                            cloud_name=cloud_name,
+                                                                            cloud_tenant=cloud_tenant,
+                                                                            tenant=tenant)
+
                                     tenant_ref = conv_utils.get_object_ref(cloud_tenant, 'tenant')
                                     new_network_service = nsxt_util.create_network_service_obj(ns_name,
                                                                                                alb_vs["se_group_ref"],
                                                                                                ns_cloud_ref, ns_vrf_ref,
                                                                                                floating_ip, tenant_ref)
                                     alb_config["NetworkService"].append(new_network_service)
-                                    is_network_service_created["{}-{}".format(pci_se_group_name, tier1_lr)] = True
+                                    new_network_service_list.append(new_network_service)
+                                    is_network_service_created["{}-{}-{}".format(pci_se_group_name, cloud_name, ns_vrf_name)] = new_network_service
 
                                 vs_list_with_snat_deactivated.append(alb_vs["name"])
 
@@ -609,14 +640,14 @@ class VsConfigConv(object):
                                         type="V4"
                                     )
                                     alb_vs["snat_ip"].append(snat_ip)
-                                    alb_vs["se_group_ref"] = conv_utils.get_object_ref("Default-Group",
+                                    alb_vs["se_group_ref"] = conv_utils.get_object_ref(segroup,
                                                                                        'serviceenginegroup',
                                                                                        cloud_name=cloud_name,
                                                                                        cloud_tenant=cloud_tenant,
                                                                                        tenant=cloud_tenant)
 
                             if pl_config[0]["snat_translation"].get("type") == "LBSnatAutoMap":
-                                alb_vs["se_group_ref"] = conv_utils.get_object_ref("Default-Group",
+                                alb_vs["se_group_ref"] = conv_utils.get_object_ref(segroup,
                                                                                    'serviceenginegroup',
                                                                                    cloud_name=cloud_name,
                                                                                    cloud_tenant=cloud_tenant,
@@ -694,9 +725,10 @@ class VsConfigConv(object):
                     if is_pg_created:
                         self.add_sorry_pool_member_to_poolgroup(alb_config, main_pool_ref, sorry_pool_ref)
                     else:
-                        self.attach_pool_to_sry_pool_group(alb_config, main_pool_ref,
-                                                           sorry_pool_ref, tenant, cloud_name)
-                        main_pool_ref = sorry_pool_ref
+                        if pool_present:
+                            sorry_pool_ref = self.attach_pool_to_sry_pool_group(alb_config, main_pool_ref,
+                                                            sorry_pool_ref, tenant, cloud_name)
+                        main_pool_ref = f"{sorry_pool_ref}"
                         is_pg_created = True
 
                 if is_pg_created:
@@ -810,27 +842,39 @@ class VsConfigConv(object):
                     LOG.debug('[VirtualService] Skipped Attribute {}:{}'.format(lb_vs['display_name'],
                                                                                 conv_status['skipped']))
 
-                LOG.info('[VirtualService] Migration completed for HM {}'.format(lb_vs['display_name']))
+                LOG.info('[VirtualService] Migration completed for VS {}'.format(lb_vs['display_name']))
             except Exception as e:
-                LOG.error("[VirtualService] Failed to convert VirtualService: {}".format(e))
+                LOG.error("[VirtualService] Error while converting VirtualService: {}".format(e))
                 update_count('error')
-                LOG.error("[VirtualServer] Failed to convert Monitor: %s" % lb_vs['display_name'],
+                LOG.error("[VirtualServer] Failed to convert VirtualService: %s" % lb_vs['display_name'],
                           exc_info=True)
                 conv_utils.add_status_row('virtualservice', None, lb_vs['display_name'],
                                           conv_const.STATUS_ERROR, "Conversion failure")
         for cert in converted_alb_ssl_certs:
-            indirect = []
-            u_ignore = []
-            ignore_for_defaults = {}
-            conv_status = conv_utils.get_conv_status(
-                [], indirect, ignore_for_defaults, [],
-                u_ignore, [])
+            conv_status = conv_utils.get_conv_status([], [], {}, cert, [], [])
             conv_utils.add_conv_status('ssl_key_and_certificate', None, cert['name'], conv_status,
                                        [{"ssl_cert_key": cert}])
+
+        for new_ap in new_pci_app_profile_list:
+            conv_status = conv_utils.get_conv_status([], [], {}, new_ap)
+            conv_utils.add_conv_status('applicationprofile', None, new_ap['name'], conv_status, new_ap)
+
+        for new_service_engine in new_service_engine_group_list:
+            conv_status = conv_utils.get_conv_status([], [], {}, new_service_engine)
+            conv_utils.add_conv_status('serviceenginegroup', None, new_service_engine['name'], conv_status,
+                                       new_service_engine)
+
+        for new_network_service in new_network_service_list:
+            conv_status = conv_utils.get_conv_status([], [], {}, new_network_service)
+            conv_utils.add_conv_status('networkservice', None, new_network_service['name'], conv_status,
+                                       new_network_service)
+
         if self.object_merge_check:
             self.update_ssl_key_refernce(alb_config)
             self.update_pki_refernce(alb_config)
 
+        self.verify_must_checks(alb_config)
+
     def get_vs_app_profile_ref(self, alb_profile_config, profile_name, object_merge_check,
                                merge_object_mapping, profile_type, tenant):
         if object_merge_check:
@@ -1163,24 +1207,25 @@ class VsConfigConv(object):
         :param avi_pool_list: List of pools to search pool object
         :param pool_ref: name of the pool
         """
-        for pool_obj in avi_pool_list:
-            if pool_ref == pool_obj["name"]:
-                pool_obj["placement_networks"] = list()
-                for sub in pool_segment:
-                    ip_addreses = dict(
-                        addr=sub["subnets"]["network_range"].split("/")[0],
-                        type="V4"
-                    )
-                    subnets = dict(
-                        subnet={
-                            "ip_addr": ip_addreses,
-                            "mask": sub["subnets"]["network_range"].split("/")[-1]
-                        },
-                        network_ref=conv_utils.get_object_ref(
-                            sub["seg_name"], 'network', tenant=tenant, cloud_name=cloud_name)
-                    )
-                    pool_obj["placement_networks"].append(subnets)
-                break
+        if pool_segment:
+            for pool_obj in avi_pool_list:
+                if pool_ref == pool_obj["name"]:
+                    pool_obj["placement_networks"] = list()
+                    for sub in pool_segment:
+                        ip_addreses = dict(
+                            addr=sub["subnets"]["network_range"].split("/")[0],
+                            type="V4"
+                        )
+                        subnets = dict(
+                            subnet={
+                                "ip_addr": ip_addreses,
+                                "mask": sub["subnets"]["network_range"].split("/")[-1]
+                            },
+                            network_ref=conv_utils.get_object_ref(
+                                sub["seg_name"], 'network', tenant=tenant, cloud_name=cloud_name)
+                        )
+                        pool_obj["placement_networks"].append(subnets)
+                    break
 
     def get_name(self, url):
 
@@ -1235,7 +1280,7 @@ class VsConfigConv(object):
     def add_port_to_pool(self, pool_name, alb_config, lb_vs):
         for pool in alb_config['Pool']:
             if pool_name == pool["name"]:
-                pool['default_port'] = int(lb_vs.get['default_pool_member_ports'][0])
+                pool['default_port'] = int(lb_vs.get('default_pool_member_ports')[0])
                 break
 
     def add_teir_to_poolgroup(self, pg_ref, alb_config, tier1_lr):
@@ -1243,7 +1288,6 @@ class VsConfigConv(object):
                       if obj['name'] == pg_ref]
         if pool_group:
             pool_group = pool_group[0]
-            pool_group['tier1_lr'] = tier1_lr
             for member in pool_group['members']:
                 pool_name = conv_utils.get_name(member['pool_ref'])
                 self.add_tier_to_pool(pool_name, alb_config, tier1_lr)
@@ -1295,6 +1339,8 @@ class VsConfigConv(object):
             pool_ref=conv_utils.get_object_ref(main_pool_ref, 'pool', tenant=tenant, cloud_name=cloud_name)
         )
         sry_pool_group['members'].append(pool_member)
+        sry_pool_group['name'] = f"{main_pool_ref}-{str(random.randint(0, 20))}"
+        return sry_pool_group['name']
 
     def update_poolgroup_with_ssl(self, alb_config, nsx_lb_config, lb_vs, pg_name,
                                   prefix, tenant,
@@ -1344,7 +1390,8 @@ class VsConfigConv(object):
                 ssl_key_name = pool['ssl_key_and_certificate_ref'].split('name=')[-1]
                 ssl_key_ref = pool['ssl_key_and_certificate_ref'].split(ssl_key_name)[0]
                 ssl_key_name = self.merge_object_mapping['ssl_cert_key'].get(ssl_key_name)
-                pool['ssl_key_and_certificate_ref'] = ssl_key_ref + ssl_key_name
+                if ssl_key_name:
+                    pool['ssl_key_and_certificate_ref'] = ssl_key_ref + ssl_key_name
 
         for vs in alb_config['VirtualService']:
             if vs.get('ssl_key_and_certificate_refs'):
@@ -1353,7 +1400,8 @@ class VsConfigConv(object):
                     ssl_key_name = vs_ssl.split('name=')[-1]
                     ssl_key_ref = vs_ssl.split(ssl_key_name)[0]
                     ssl_key_name = self.merge_object_mapping['ssl_cert_key'].get(ssl_key_name)
-                    vs_ssl_list[index] = ssl_key_ref + ssl_key_name
+                    if ssl_key_name:
+                        vs_ssl_list[index] = ssl_key_ref + ssl_key_name
 
     def update_pki_refernce(self, alb_config):
         for pool in alb_config['Pool']:
@@ -1361,18 +1409,81 @@ class VsConfigConv(object):
                 pki_name = pool['pki_profile_ref'].split('name=')[-1]
                 pki_profile_ref = pool['pki_profile_ref'].split(pki_name)[0]
                 pki_name = self.merge_object_mapping['pki_profile'].get(pki_name)
-                pool['pki_profile_ref'] = pki_profile_ref + pki_name
+                if pki_name:
+                    pool['pki_profile_ref'] = pki_profile_ref + pki_name
 
         for app in alb_config['ApplicationProfile']:
             if app.get('pki_profile_ref'):
                 pki_name = app['pki_profile_ref'].split('name=')[-1]
                 pki_profile_ref = app['pki_profile_ref'].split(pki_name)[0]
                 pki_name = self.merge_object_mapping['pki_profile'].get(pki_name)
-                app['pki_profile_ref'] = pki_profile_ref + pki_name
+                if pki_name:
+                    app['pki_profile_ref'] = pki_profile_ref + pki_name
 
         for app in alb_config['NetworkProfile']:
             if app.get('pki_profile_ref'):
                 pki_name = app['pki_profile_ref'].split('name=')[-1]
                 pki_profile_ref = app['pki_profile_ref'].split(pki_name)[0]
                 pki_name = self.merge_object_mapping['pki_profile'].get(pki_name)
-                app['pki_profile_ref'] = pki_profile_ref + pki_name
+                if pki_name:
+                    app['pki_profile_ref'] = pki_profile_ref + pki_name
+
+    def verify_must_checks(self, alb_config):
+        # If https monitor is attached to a VS pool and ssl profile is not attached to with of VS or monitor then
+        # add a default system SSL profile to https type monitor
+        self.verify_must_checks_for_https_healh_monitor(alb_config)
+
+    def verify_must_checks_for_https_healh_monitor(self, alb_config):
+        LOG.debug("Starting must check verification for https health monitor ssl profile")
+
+        alb_pool_name_object_dict = dict()
+        alb_pool_group_name_object_dict = dict()
+        alb_hm_name_object_dict = dict()
+
+        for alb_pool in alb_config['Pool']:
+            alb_pool_name_object_dict[alb_pool['name']] = alb_pool
+        for alb_pool_group in alb_config['PoolGroup']:
+            alb_pool_group_name_object_dict[alb_pool_group['name']] = alb_pool_group
+        for alb_hm in alb_config['HealthMonitor']:
+            alb_hm_name_object_dict[alb_hm['name']] = alb_hm
+
+        for alb_vs in alb_config['VirtualService']:
+            if alb_vs.get('pool_ref'):
+                self.attach_ssl_profile_to_https_monitor(alb_vs.get('name'), alb_vs.get('pool_ref'),
+                                                         alb_pool_name_object_dict, alb_hm_name_object_dict)
+            elif alb_vs.get('pool_group_ref'):
+                pool_group_name = alb_vs['pool_group_ref'].split("name=")[1].split("&")[0]
+                pool_group_obj = alb_pool_group_name_object_dict.get(pool_group_name)
+                if pool_group_obj and pool_group_obj.get("members"):
+                    for pool_member in pool_group_obj.get("members"):
+                        self.attach_ssl_profile_to_https_monitor(alb_vs.get('name'), pool_member.get('pool_ref'),
+                                                                 alb_pool_name_object_dict, alb_hm_name_object_dict)
+            else:
+                LOG.debug(f"No pool group or pool attached to VS: {alb_vs.get('name')}")
+
+        LOG.debug("Completed must check verification for https health monitor ssl profile")
+
+    def attach_ssl_profile_to_https_monitor(self, vs_name, pool_ref, alb_pool_name_object_dict, alb_hm_name_object_dict):
+        is_ssl_configured = False
+
+        pool_name = pool_ref.split("name=")[1].split("&")[0]
+        pool_obj = alb_pool_name_object_dict.get(pool_name)
+        if pool_obj.get('ssl_profile_ref'):
+            is_ssl_configured = True
+        if not is_ssl_configured:
+            hm_name_list = pool_obj.get('health_monitor_refs')
+            if hm_name_list:
+                for hm in hm_name_list:
+                    hm_name = hm.split("name=")[1].split("&")[0]
+                    hm_obj = alb_hm_name_object_dict.get(hm_name)
+                    if hm_obj.get('type') == 'HEALTH_MONITOR_HTTPS' and not hm_obj.get('ssl_attributes'):
+                        LOG.debug(f"Not found ssl profile for https monitor type for VS: {vs_name}, "
+                                  f"Pool: {pool_obj.get('name')}, HM: {hm_obj.get('name')}. "
+                                  f"Attaching system default ssl profile.")
+                        ssl_attributes = {
+                            "ssl_profile_ref": f"/api/sslprofile/?tenant=admin&name=System-Standard"
+                        }
+                        hm_obj["https_monitor"]['ssl_attributes'] = ssl_attributes
+        else:
+            LOG.debug(f"SSL profile is already attached to Pool: {pool_obj.get('name')}, "
+                      f"VS: {vs_name}")
